<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <el-col :span="16">
        <el-form-item label="地址">
          <div>
            <li_area_select
              ref="areaSelect"
              v-model="searchAddress"
            ></li_area_select>
          </div>
        </el-form-item>
      </el-col>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:travelexpensestandard:add']"
          >新增</el-button
        >
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="travelexpensestandardList"
      @selection-change="handleSelectionChange"
      border
    >
      <el-table-column label="省名称" align="center" prop="provincename" />
      <el-table-column label="市名称" align="center" prop="cityname" />
      <el-table-column label="区\县街道" align="center" prop="townname" />
      <el-table-column
        label="旺季（开始月份）"
        align="center"
        prop="begindate"
        width="180"
      >
      </el-table-column>
      <el-table-column
        label="旺季（结束月份）"
        align="center"
        prop="enddate"
        width="180"
      >
      </el-table-column>
      <el-table-column
        label="省级及相当职级人员费用"
        align="center"
        prop="firstlevelcost"
      />
      <el-table-column
        label="正副厅长及相当职级人员费用"
        align="center"
        prop="secondlevelcost"
      />
      <el-table-column
        label="其他人员费用"
        align="center"
        prop="thirdlevelcost"
      />
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:travelexpensestandard:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:travelexpensestandard:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改住宿费限额标准对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="900px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-row :gutter="20">
          <el-col :span="24">
            <el-form-item label="地址">
              <div>
                <li_area_select
                  ref="formAreaSelect"
                  v-model="formAddress"
                ></li_area_select>
              </div>
            </el-form-item>
          </el-col>
        </el-row>

        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item
              label="旺季（开始月份）"
              prop="begindate"
              label-width="200px"
            >
              <el-input v-model="form.begindate" placeholder="请输入起始月份" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item
              label="旺季（结束月份）"
              prop="enddate"
              label-width="200px"
            >
              <el-input v-model="form.enddate" placeholder="请输入起始月份" />
            </el-form-item>
          </el-col>
        </el-row>

        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item
              label="省级及相当职级人员费用"
              prop="firstlevelcost"
              label-width="200px"
            >
              <el-input
                v-model="form.firstlevelcost"
                placeholder="请输入省级及相当职级人员费用"
              />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item
              label="正副厅长及相当职级人员费用"
              prop="secondlevelcost"
              label-width="200px"
            >
              <el-input
                v-model="form.secondlevelcost"
                placeholder="请输入正副厅长及相当职级人员费用"
              />
            </el-form-item>
          </el-col>
        </el-row>

        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item
              label="其他人员费用"
              prop="thirdlevelcost"
              label-width="200px"
            >
              <el-input
                v-model="form.thirdlevelcost"
                placeholder="请输入其他人员费用"
              />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listTravelexpensestandard,
  getTravelexpensestandard,
  delTravelexpensestandard,
  addTravelexpensestandard,
  updateTravelexpensestandard,
  exportTravelexpensestandard,
} from "@/api/system/travelexpensestandard";
import request from "@/utils/request";
import Li_area_select from "@/components/Address";

export default {
  name: "Travelexpensestandard",
  components: {
    Li_area_select,
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 住宿费限额标准表格数据
      travelexpensestandardList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        provincecode: null,
        citycode: null,
        towncode: null,
        begindate: null,
        enddate: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
      searchAddress: {
        sheng: "",
        shi: "",
        qu: "",
        organizationname: null,
      },
      formAddress: {
        sheng: "",
        shi: "",
        qu: "",
        organizationname: null,
      },
      areaJson: "/project/dict/treeselect", // 上传的图片服务器地址
      //areaJson: './../address.json',
      addressArray: [], //所有数据
      provinceArray: [],
      cityArray: [],
      areaArray: [],
      caddress: null,
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询住宿费限额标准列表 */
    getList() {
      this.loading = true;
      listTravelexpensestandard(this.queryParams).then((response) => {
        this.travelexpensestandardList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        provincecode: null,
        citycode: null,
        towncode: null,
        begindate: null,
        enddate: null,
        firstlevelcost: null,
        secondlevelcost: null,
        thirdlevelcost: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.queryParams.provincecode = this.$refs.areaSelect.getSheng();
      this.queryParams.provincename = this.formAddress.sheng;

      this.queryParams.citycode = this.$refs.areaSelect.getShi();
      this.queryParams.cityname = this.formAddress.shi;
      if(this.queryParams.cityname == "直辖市"){
        this.queryParams.towncode = this.$refs.areaSelect.getQu();
        this.queryParams.townname = this.formAddress.qu;
      }
      else{
        this.queryParams.towncode = null;
        this.queryParams.townname = null;
      }
      
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.searchAddress.sheng = '';
      this.searchAddress.shi = '';
      this.searchAddress.qu = '';
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加住宿费限额标准";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids;
      getTravelexpensestandard(id).then((response) => {
        this.formAddress.sheng = response.data.provincename;
        this.formAddress.shi = response.data.cityname;
        this.formAddress.qu = response.data.townname;
        this.form = response.data;
        this.open = true;
        this.title = "修改住宿费限额标准";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          //获取省市区明细
          this.form.provincecode = this.$refs.formAreaSelect.getSheng();
          this.form.provincename = this.formAddress.sheng;

          this.form.citycode = this.$refs.formAreaSelect.getShi();
          this.form.cityname = this.formAddress.shi;

          if (this.form.cityname == "直辖市") {
            this.form.towncode = this.$refs.formAreaSelect.getQu();
            this.form.townname = this.formAddress.qu;
          } else {
            this.form.towncode = "";
            this.form.townname = "";
          }
          console.log(this.form);
          if (this.form.id != null) {
            updateTravelexpensestandard(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addTravelexpensestandard(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm('是否确认删除住宿费限额标准编号为"' + ids + '"的数据项？')
        .then(function () {
          return delTravelexpensestandard(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$modal
        .confirm("是否确认导出所有住宿费限额标准数据项？")
        .then(() => {
          this.exportLoading = true;
          return exportTravelexpensestandard(queryParams);
        })
        .then((response) => {
          this.$download.name(response.msg);
          this.exportLoading = false;
        })
        .catch(() => {});
    },

    //选择省份
    getCityData(val) {
      //清空市，和区
      this.caddress.shi = "";
      this.caddress.qu = "";
      this.$emit("change", this.caddress); //发送改变
      for (let ad of this.addressArray) {
        if (ad.areaname === val) {
          this.cityArray = ad.subarea;
          return;
        }
      }
    },
    getAreaData(val) {
      //清空区
      this.caddress.qu = "";
      this.$emit("change", this.caddress); //发送改变
      for (let area of this.cityArray) {
        if (area.areaname === val) {
          this.areaArray = area.subarea;
          return;
        }
      }
    },
    //地区数据变动后
    onAreaChanged(val) {
      this.$emit("change", this.caddress); //发送改变
    },
  },
  mounted() {},
};
</script>